import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import isEmpty from 'is-empty';
import './input.scss';

class TextInput extends Component {
  render() {
    const {
      icon = {},
      label,
      size,
      containerClass = '',
      labelClass = '',
      message,
      id,
      actionItem = {
        show: false,
        label: '',
        onClick: () => { }
      },
      placeholder = '',
      required = false,
      disabled = false,
      loading = false,
      inputRef = () => { },
      isMenuOpen = false,
      ...inputProps
    } = this.props;
    return (
      <div className={cx('ui-input-block', containerClass)}>
        {
          label &&
          <label className={cx('ui-input-label', labelClass, { 'is-required': required })} htmlFor={disabled ? '' : id}>{label}</label>
        }
        <div className='ui-input-wrapper'>
          {
            icon.left &&
            <span className='pk-select-icon ui-input-icon left'>
              {icon.left}
            </span>
          }
          {
            disabled
              ?
              <input ref={inputRef} placeholder={placeholder} className={cx('ui-input disabled', { 'is-small': size === 'small', 'ui-input-with-left-icon': !isEmpty(icon.left), 'ui-input-with-right-icon': !isEmpty(icon.right) })} defaultValue={inputProps.value} />
              :
              <input ref={inputRef} id={id} placeholder={placeholder} autoComplete='off' className={cx('ui-input', { 'is-small': size === 'small', 'ui-input-with-left-icon': !isEmpty(icon.left), 'ui-input-with-right-icon': !isEmpty(icon.right), 'read-only': inputProps.readOnly })} {...inputProps} />
          }
          {
            loading ?
              <div className='pk-select-loader-wrapper'>
                <div className='pk-select-loader'>
                  <svg viewBox='22 22 44 44'>
                    <circle className='path' cx='44' cy='44' r='19.5' fill='none' strokeWidth='4' />
                  </svg>
                </div>
              </div>
              :
              !isEmpty(icon.right)
                ?
                <span className={cx('pk-select-icon ui-input-icon right', icon.right.additionalClasses, { 'upside-down': isMenuOpen })} {...icon.right.props}>
                  <span className='icon-wrapper'>
                    {icon.right.component}
                  </span>
                </span>
                : null
          }
        </div>
        {message && <span className='helper-message'>{message}</span>}
        {actionItem.show && <span className='ui-input-action-item helper-message' onClick={() => actionItem.onClick()}>{actionItem.label}</span>}
      </div>
    );
  }
}

TextInput.propTypes = {
  icon: PropTypes.shape({
    left: PropTypes.any,
    right: PropTypes.any
  }),
  required: PropTypes.bool,
  disabled: PropTypes.bool,
  label: PropTypes.string,
  size: PropTypes.string,
  placeholder: PropTypes.string,
  containerClass: PropTypes.string,
  labelClass: PropTypes.string,
  message: PropTypes.string,
  actionItem: PropTypes.shape({
    show: PropTypes.bool,
    label: PropTypes.string,
    onClick: PropTypes.func,
  }),
  id: PropTypes.string,
  loading: PropTypes.bool,
};

export default TextInput;
